#' @details
#'  \tabular{ll}{
#'   **Package:** \tab arkhe \cr
#'   **Type:** \tab Package \cr
#'   **Version:** \tab 1.3.0 \cr
#'   **License:** \tab GPL-3 \cr
#'   **Zenodo:** \tab \doi{10.5281/zenodo.3526659} \cr
#'  }
#'
#' @section Package options:
#'  `arkhe` uses the following [options()] to configure behavior:
#'  * `arkhe.verbose`: a [`logical`] scalar. Should \R report extra information
#'    on progress? Defaults to `TRUE`.
#'
#' @author
#'  **Full list of authors and contributors** (alphabetic order):
#'
#'  \tabular{ll}{
#'   Nicolas Frerebeau \tab *Université Bordeaux Montaigne, France* \cr
#'   Brice Lebrun \tab *Université Bordeaux Montaigne, France* \cr
#'  }
#'
#'  **Package maintainer**
#'
#'  Nicolas Frerebeau\cr
#'  \email{nicolas.frerebeau@@u-bordeaux-montaigne.fr}
#'
#'  Archéosciences Bordeaux (UMR 6034)\cr
#'  Maison de l'Archéologie\cr
#'  Université Bordeaux Montaigne\cr
#'  F-33607 Pessac cedex\cr
#'  France
#' @name arkhe-package
#' @aliases arkhe
#' @docType package
#' @keywords internal
"_PACKAGE"

#' @importFrom methods setGeneric setMethod .valueClassTest
NULL
